@@ -7,11 +7,11 @@ Author(s)
 MJP
 """
 
-# Import third-party packages
+# Standdard imports
 # -----------------------
 import json
 from jsonschema import validate
-
+import pkgutil
 
 
 # local imports
@@ -22,12 +22,19 @@ from . import filepaths
 
 # IO function(s)
 # -----------------------
-def load_json( json_filepath ):
-    """ Load a json file into a dictionary
-    """
-    with open( json_filepath ) as f:
-        return json.load(f)
+#def load_json( json_filepath ):
+#    """ Load a json file into a dictionary
+#    """
+#    with open( json_filepath ) as f:
+#        return json.load(f)
         
+def load_schema( ):
+    """ Use pkgutil to load schema into a dictionary
+    """
+    # use pkgutil to get resource ...
+    raw_bytes = pkgutil.get_data(__name__ , filepaths.schema_relative_filepath)
+    return json.loads(raw_bytes.decode('utf-8'))
+
 
 
 
@@ -50,7 +57,7 @@ def validate_mpcorb( arg ):
 
     # validate
     # NB # If no exception is raised by validate(), the instance is valid.
-    validate(instance=data, schema=load_json( filepaths.mpcorb_schema ))
+    validate(   instance = data,  schema = load_schema( ))
     
     return True
 
